Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5489)

Unified Diff: chrome/browser/zygote_main_linux.cc

Issue 522020: clang support (Closed)
Patch Set: lgtm Created 10 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/zygote_main_linux.cc
diff --git a/chrome/browser/zygote_main_linux.cc b/chrome/browser/zygote_main_linux.cc
index 20b03524db89cd23e7c5e80c3301a53738701251..b4dd7bea1f4872c131907a65767943b87ad5aa99 100644
--- a/chrome/browser/zygote_main_linux.cc
+++ b/chrome/browser/zygote_main_linux.cc
@@ -50,9 +50,10 @@
#include "unicode/timezone.h"
-#if defined(ARCH_CPU_X86_FAMILY) && !defined(CHROMIUM_SELINUX)
+#if defined(ARCH_CPU_X86_FAMILY) && !defined(CHROMIUM_SELINUX) && \
+ !defined(__clang__)
// The seccomp sandbox is enabled on all ia32 and x86-64 processor as long as
// we aren't using SELinux.
Nico 2010/09/17 23:52:40 is there a reason for this?
Evan Martin 2010/09/17 23:54:06 Seccomp is really gcc specific right now.
#define SECCOMP_SANDBOX
@@ -50,9 +50,10 @@
// The seccomp sandbox is enabled on all ia32 and x86-64 processor as long as
-// we aren't using SELinux.
+// we aren't using SELinux or clang.
Nico 2010/09/17 23:52:40 is there a reason for this?
Evan Martin 2010/09/17 23:54:06 Seccomp is really gcc specific right now.
#endif

Powered by Google App Engine
This is Rietveld 408576698